==> setup-wizard-dist_7.4.orig.tar.xz: README.md <==
# First Boot Setup #

When distribution starts for the first time, it won't automatically connect
to the public Tor network. This is useful for users who want to hide Tor from
their ISP. Anon Connection Wizard is automatically started, which educates
about different methods to connect (public Tor network, bridges, etc.).

Also automatically starts the Distribution Repository Tool (if installed), so
the user can decide whether to use Distribution's Repository and if yes,
choose which one.
## How to install `setup-wizard-dist` using apt-get ##

1\. Download Whonix's Signing Key.

```
wget https://www.whonix.org/patrick.asc
```

Users can [check Whonix Signing Key](https://www.whonix.org/wiki/Whonix_Signing_Key) for better security.

2\. Add Whonix's signing key.

```
sudo cp ~/derivative.asc /usr/share/keyrings/derivative.asc
```

3\. Add Whonix's APT repository.

```
echo "deb [signed-by=/usr/share/keyrings/derivative.asc] https://deb.whonix.org bullseye main contrib non-free" | sudo tee /etc/apt/sources.list.d/derivative.list
```

4\. Update your package lists.

```
sudo apt-get update
```

5\. Install `setup-wizard-dist`.

```
sudo apt-get install setup-wizard-dist
```

## How to Build deb Package from Source Code ##

Can be build using standard Debian package build tools such as:

```
dpkg-buildpackage -b
```

See instructions. (Replace `generic-package` with the actual name of this package `setup-wizard-dist`.)

* **A)** [easy](https://www.whonix.org/wiki/Dev/Build_Documentation/generic-package/easy), _OR_
* **B)** [including verifying software signatures](https://www.whonix.org/wiki/Dev/Build_Documentation/generic-package)

## Contact ##

* [Free Forum Support](https://forums.whonix.org)
* [Professional Support](https://www.whonix.org/wiki/Professional_Support)

## Donate ##

`setup-wizard-dist` requires [donations](https://www.whonix.org/wiki/Donate) to stay alive!

==> setup-wizard-dist_7.7.orig.tar.xz: README.md <==
# First Boot Setup #

When distribution starts for the first time, it won't automatically connect
to the public Tor network. This is useful for users who want to hide Tor from
their ISP. Anon Connection Wizard is automatically started, which educates
about different methods to connect (public Tor network, bridges, etc.).

Also automatically starts the Distribution Repository Tool (if installed), so
the user can decide whether to use Distribution's Repository and if yes,
choose which one.
## How to install `setup-wizard-dist` using apt-get ##

1\. Download the APT Signing Key.

```
wget https://www.whonix.org/derivative.asc
```

Users can [check Whonix Signing Key](https://www.whonix.org/wiki/Whonix_Signing_Key) for better security.

2\. Add the APT Signing Key..

```
sudo cp ~/derivative.asc /usr/share/keyrings/derivative.asc
```

3\. Add the derivative repository.

```
echo "deb [signed-by=/usr/share/keyrings/derivative.asc] https://deb.whonix.org bullseye main contrib non-free" | sudo tee /etc/apt/sources.list.d/derivative.list
```

4\. Update your package lists.

```
sudo apt-get update
```

5\. Install `setup-wizard-dist`.

```
sudo apt-get install setup-wizard-dist
```

## How to Build deb Package from Source Code ##

Can be build using standard Debian package build tools such as:

```
dpkg-buildpackage -b
```

See instructions. (Replace `generic-package` with the actual name of this package `setup-wizard-dist`.)

* **A)** [easy](https://www.whonix.org/wiki/Dev/Build_Documentation/generic-package/easy), _OR_
* **B)** [including verifying software signatures](https://www.whonix.org/wiki/Dev/Build_Documentation/generic-package)

## Contact ##

* [Free Forum Support](https://forums.whonix.org)
* [Professional Support](https://www.whonix.org/wiki/Professional_Support)

## Donate ##

`setup-wizard-dist` requires [donations](https://www.whonix.org/wiki/Donate) to stay alive!
